@@ -5,7 +5,7 @@ from . import models
 def generate_source(**kwargs) -> models.Source:
     obj, created = models.Source.objects.get_or_create(
         code=id_generator(),
-        type=kwargs.get('type', models.SourceType.SAGE_SQL_CONNECTOR_V1),
+        type=kwargs.get('type', models.SourceType.SQL_SAGE_GATEWAY_V1),
     )
     return obj
 
